@@ -443,6 +443,16 @@ make_setup_recipe(){
 
 configure_recipe(){
     # local PS5=$PS4; PS4=" + configure_recipe> "; set -x
+
+    # dak gets all neurotic about file timestamps older than 1975
+    # new tarballs from Hackage have files with mtimes at the
+    # beginning of the epoch, so work around this pair of silliness
+    # by setting old mtimes to 1998
+    reftime=$(mktemp)
+    touch -d 1975-01-01 "${reftime}"
+    find . \! -newer "${reftime}" -exec touch -d 1998-01-01 {} \;
+    rm "${reftime}"
+
     hc=`packages_hc`
 
     ENABLE_PROFILING=`{ for i in ${DEB_PACKAGES}; do package_ext $i | grep prof; done; } | LC_ALL=C sort -u | sed 's/prof/--enable-library-profiling/'`
